@@ -72,7 +72,7 @@ Pinged infrequently to discover the current week number, year and week type.
 The actual schedule of games is taken from the schedule module.
 """
 
-_POST_URL = "http://static.nfl.com/liveupdate/scorestrip/postseason/ss.xml"
+_CUR_SCHEDULE_URL = "http://static.nfl.com/liveupdate/scorestrip/postseason/ss.xml"
 """
 The URL for the XML schedule of the post season. This is only used
 during the post season.
